mlx_compile_mode_ enum
\defgroup compile Compilation operations / /**@{
Values
- MLX_COMPILE_MODE_DISABLED → const mlx_compile_mode_
-
const mlx_compile_mode_(0) - MLX_COMPILE_MODE_NO_SIMPLIFY → const mlx_compile_mode_
-
const mlx_compile_mode_(1) - MLX_COMPILE_MODE_NO_FUSE → const mlx_compile_mode_
-
const mlx_compile_mode_(2) - MLX_COMPILE_MODE_ENABLED → const mlx_compile_mode_
-
const mlx_compile_mode_(3)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → mlx_compile_mode_
Constants
-
values
→ const List<
mlx_compile_mode_> - A constant List of the values in this enum, in order of their declaration.