mlx_io_vtable_ class final
Virtual table for custom IO reader and writer objects.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
free
↔ Pointer<
NativeFunction< Void Function(Pointer< >Void> )> -
getter/setter pair
-
good
↔ Pointer<
NativeFunction< Bool Function(Pointer< >Void> )> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
is_open
↔ Pointer<
NativeFunction< Bool Function(Pointer< >Void> )> -
getter/setter pair
-
label
↔ Pointer<
NativeFunction< Pointer< >Char> Function(Pointer<Void> )> -
getter/setter pair
-
read
↔ Pointer<
NativeFunction< Void Function(Pointer< >Void> , Pointer<Char> , Size)> -
getter/setter pair
-
read_at_offset
↔ Pointer<
NativeFunction< Void Function(Pointer< >Void> , Pointer<Char> , Size, Size)> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
seek
↔ Pointer<
NativeFunction< Void Function(Pointer< >Void> , Int64, Int)> -
getter/setter pair
-
tell
↔ Pointer<
NativeFunction< Size Function(Pointer< >Void> )> -
getter/setter pair
-
write
↔ Pointer<
NativeFunction< Void Function(Pointer< >Void> , Pointer<Char> , Size)> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited